@@ -49,9 +49,9 @@ void digitDownMM2();
 
 void drawAlarmDigits(SDL_Surface *screenBuff, char *alarmHHMM);
 
-void drawAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int digitValue);
+void drawAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int digitValue, SDL_Rect *digitPosRect);
 
-void animateAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int oldDigitValue, int newDigitValue, int frames);
+void animateAlarmScrollerDigit(SDL_Surface *screenBuff, int digitIndex, int oldDigitValue, int newDigitValue, int frames, SDL_Rect *digitPosRect);
 
 void drawAllAlarmDays(SDL_Surface *screenBuff);
 
